Distance-based description of BU shape
============================================

.. featurizer::  PairwiseDistanceHist
    :id: PairwiseDistanceHist
    :considers_geometry: True
    :considers_structure_graph: False
    :encodes_chemistry: False
    :scope: bu
    :scalar: False

.. featurizer::  PairwiseDistanceStats
    :id: PairwiseDistanceStats
    :considers_geometry: True
    :considers_structure_graph: False
    :encodes_chemistry: False
    :scope: bu
    :scalar: False
